@@ -1,4 +1,4 @@
-__version__ = "1.0.92"
+__version__ = "1.0.93"
 
 import kappadata.caching
 import kappadata.common
@@ -85,6 +85,11 @@ from .wrappers.sample_wrappers.one_hot_wrapper import OneHotWrapper
 from .wrappers.sample_wrappers.x_transform_wrapper import XTransformWrapper
 from .wrappers.torch_wrapper import TorchWrapper
 # utils
-from .utils.transform_utils import get_denorm_transform, get_norm_transform, flatten_transform
+from .utils.transform_utils import (
+    flatten_transform,
+    get_denorm_transform,
+    get_norm_transform,
+    get_x_transform,
+)
 # factory
 from .factory import object_to_transform
\ No newline at end of file
