@@ -1,2 +1,5 @@
+# base
+from .base.kd_compose_collator import KDComposeCollator
+#
 from .kd_mix_collator import KDMixCollator
 from .pad_sequences_collator import PadSequencesCollator
