@@ -46,5 +46,8 @@ class KDSubset(Subset):
     def all_wrapper_types(self):
         return [type(self)] + self.dataset.all_wrapper_types
 
+    def worker_init_fn(self, rank, **kwargs):
+        self.dataset.worker_init_fn(rank, **kwargs)
+
     def __getitem__(self, idx):
         raise UseModeWrapperException
